@@ -5,6 +5,7 @@ import time
 import signal
 import logging
 import os
+import importlib
 
 from stretch_body.device import Device
 import stretch_body.base as base
@@ -130,7 +131,12 @@ class Robot(Device):
             self.status['head']=self.head.status
 
         if self.params['use_wacc']:
-            self.wacc=wacc.Wacc()
+            if self.params.has_key('custom_wacc'):
+                module_name = self.params['custom_wacc']['py_module_name']
+                class_name = self.params['custom_wacc']['py_class_name']
+                self.wacc=getattr(importlib.import_module(module_name), class_name)(self)
+            else:
+                self.wacc=wacc.Wacc()
             self.status['wacc']=self.wacc.status
 
         if self.params['use_end_of_arm']:
@@ -317,14 +323,8 @@ class Robot(Device):
         Blocking.
         """
         if self.head is not None:
-            # Just confirm that head motion is working
-            print '--------- Head Motion Test ----'
-            self.head.move_to('head_pan', hello_utils.deg_to_rad(-90))
-            self.head.move_to('head_tilt', hello_utils.deg_to_rad(-90))
-            time.sleep(1.0)
-            self.head.move_to('head_pan', hello_utils.deg_to_rad(0))
-            self.head.move_to('head_tilt', hello_utils.deg_to_rad(0))
-            time.sleep(1.0)
+            print '--------- Homing Head ----'
+            self.head.home()
 
         # Home the lift
         if self.lift is not None:
@@ -341,7 +341,9 @@ class Robot(Device):
             for j in self.end_of_arm.joints:
                 print  '--------- Homing ', j, '----'
                 self.end_of_arm.home(j)
-
+        #Let user know it is done
+        self.pimu.trigger_beep()
+        self.push_command()
     # ################ Helpers #################################
 
     def _pretty_print_dict(self, t, d):
